@@ -1,4 +1,4 @@
-from typing import Generic, Optional, Type, TypeVar
+from typing import Generic, List, Optional, Type, TypeVar
 
 from bson import ObjectId  # type: ignore
 
@@ -8,7 +8,7 @@ from motor_orm.model import Model
 T = TypeVar("T", bound=Model)
 
 
-class ModelService(Generic[T]):
+class ModelServiceBase(Generic[T]):
     model: Type[T]
     collection_name: Optional[str] = None
 
@@ -16,20 +16,22 @@ class ModelService(Generic[T]):
     def _get_collection_name(cls):
         return cls.collection_name or cls.model.__name__
 
-    @classmethod
-    def _model_to_db(cls, model: T) -> dict:
-        return model.dict()
-
-    @classmethod
-    def _db_to_model(cls, data: dict) -> T:
-        return cls.model(**data)
-
     def __init__(self, db: Database):
         self.db = db
         self.client = db.client
         self.collection_name = self._get_collection_name()
         self.collection = self.client[self.collection_name]
 
+
+class ModelService(ModelServiceBase, Generic[T]):
+    @classmethod
+    def _model_to_db(cls, model: T) -> dict:
+        return model.dict(by_alias=True)
+
+    @classmethod
+    def _db_to_model(cls, data: dict) -> T:
+        return cls.model(**data)
+
     async def create_collection(self):
         """
         Create custom indexes etc...
@@ -47,5 +49,21 @@ class ModelService(Generic[T]):
 
     async def insert_one(self, model: T) -> ObjectId:
         doc = self._model_to_db(model)
+
+        if '_id' in doc and doc.get('_id', None) is None:
+            doc.pop('_id')
+
         insert_result = await self.collection.insert_one(doc)
         return insert_result.inserted_id
+
+    async def insert_many(self, models: List[T]) -> List[ObjectId]:
+        docs: List[dict] = []
+
+        for m in models:
+            doc = self._model_to_db(m)
+            if '_id' in doc and doc.get('_id', None) is None:
+                doc.pop('_id')
+            docs.append(doc)
+
+        insert_result = await self.collection.insert_many(docs)
+        return insert_result.inserted_ids
